Module tooltip

Module tooltip 

Functions

plot_tooltip_label_value
Renders a single value line in the plot tooltip with truncation.
show_plot_tooltip
Shows a plot tooltip at the pointer for the given response.